<?php
if ( ! defined( 'ABSPATH' ) ) { 
    exit; // Exit if accessed directly
}

add_action('admin_init', 'swal_settings' );
add_action('admin_menu', 'sw_ajax_login_menu');




/**
 * adds plugin settings menu to admin
 */
function sw_ajax_login_menu() {
    add_menu_page('SW Ajax Login', 'SW Ajax Login', 'administrator', SWAL_PLUGIN_SETTINGS_PAGE, 'swal_settings_page', SWAL_PLUGIN_ADMIN_IMAGES.'/menu-icon.png',25);
    add_submenu_page( SWAL_PLUGIN_SETTINGS_PAGE, esc_html__('Documentation','sw-ajax-login'), esc_html__('Documentation','sw-ajax-login'),'manage_options', SWAL_PLUGIN_SETTINGS_PAGE.'-docs','swal_doc_page');
}


/**
 *
 * Adds the tab to manage the emails
 *
 */
add_filter('swal_admin_tabs_items', 'swal_add_emails_tab');

function swal_add_emails_tab( $menu_item) {

    $inserted[] = array(
          'title'  => esc_html__('Emails','sw-ajax-login'),
          'href'   => '#tab10',
          ); 

  array_splice( $menu_item, 8, 0, $inserted );

  return $menu_item;
}


/**
 *
 * Append the Login Menu item to selected menus when options are updated
 *
 */
add_action( 'updated_option', 'swal_update_deprecated_login_menu_items', 10, 3);

function swal_update_deprecated_login_menu_items($option_name, $old_value, $value) {

    // If none of the following options has been modified then return
    $options = array(
                    'swal_menu_to_append',
                    'swal_menu_item_text',
                    'swal_menu_item_custom_text',
                    'swal_login_intro_text_link',
                    'swal_pagina_account_default',
                    'swal_menu_item_logout_text',
                    'swal_menu_item_logout_custom_text',
                    );
    if (!in_array( $option_name, $options )) {
        return;
    }

    swal_add_login_menu_item_to_menus();

}


/**
 *
 * New Menus update from version 1.6.1, Update Login menu items and append to them the old submenu
 *
 */
add_action( 'admin_init', 'swal_move_deprecated_login_submenu_items', 10);

function swal_move_deprecated_login_submenu_items() {

    if (!isset($_GET['swal_nonce']) || !wp_verify_nonce($_GET['swal_nonce'], 'swal_updating_menus')) {
        return;
    }

    if (!isset($_GET['swal_update_menus']) || (isset($_GET['swal_update_menus']) && $_GET['swal_update_menus'] != 'true')) {
        return;
    }

    $x = swal_add_login_menu_item_to_menus();

    if ($x) {
        swal_delete_menu_items_from_old_submenu();
    }
   
}



/**
 * Sanitize and Register StranoWeb Ajax Login settings
 */
function swal_settings() {
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_user_thumbnail_style', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_simple_layout_width', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_double_layout_width', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_customize_popup', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_login_icons', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_register_icons', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_forgot_password_icons', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_text_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_secondary_text_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_image_text_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_link_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_buttons_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_ajax_login_background', 'sanitize_file_name' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_ajax_register_background', 'sanitize_file_name' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_ajax_forgot_password_background', 'sanitize_file_name' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_ajax_logout_background', 'sanitize_file_name' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_redirect_after_login', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_redirect_after_logout', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_custom_redirect_after_login', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_custom_redirect_after_logout', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logged_in_redirect_custom_page', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logged_in_redirect', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_menu_item_text', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_text_login', 'htmlentities' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_register_login', 'htmlentities' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_forgot_password_login', 'htmlentities' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logout_login', 'htmlentities' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_layout_style', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_overlay_login', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_overlay_logout', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_overlay_register', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_overlay_password', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_overlay_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logout_overlay_color', 'sanitize_hex_color' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_socials_login', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_native_socials_login', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_use_social_profile_picture', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_native_twitter_login', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_social_login_to_woocommerce', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'users_can_register', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_register_no_email_to_user', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_register_form_type', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_no_password_text', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_menu_item_style', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_overlay_opacity', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logout_overlay_opacity', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_menu_to_append', 'swal_sanitize_array_text_field'); // This is an array
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_login_bg_image_alignment', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_register_bg_image_alignment', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_password_bg_image_alignment', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_logout_bg_image_alignment', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_social_icons_theme', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_twitter_id', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_twitter_secret_key', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_login_remember_credentials', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_min_password_length', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_social_icons_position', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_terms_link', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_show_password_reset_password_email', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_menu_item_link_to', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_menu_item_custom_link_to', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_menu_li_class', 'sanitize_html_classes' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_menu_li_a_class', 'sanitize_html_classes' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_menu_li_a_ul_li_class', 'sanitize_html_classes' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_add_menu_li_a_ul_li_a_class', 'sanitize_html_classes' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_termsconditions_link_to', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_termsconditions_text', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_termsconditionsintro_text', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_pagina_account', 'sanitize_text_field' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_pagina_account_default', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_additional_css', 'swal_notify_import_rules_stripped' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_popup_close_icon_position', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_disable_nonces', 'intval' );
    // Auto Popup
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_enable_autopopup', 'intval' );
    register_setting( SWAL_PLUGIN_SETTINGS_PAGE . '-group', 'swal_autopopup_delay', 'intval' );


    //get the permalink just saved and flush rewrite rules
    Layers_SwAjaxLogin_free::prefix_swal_rewrite_rule();
    flush_rewrite_rules();
}

/**
 *
 * SW Ajax Login settings form
 *
 */
function swal_settings_page() {
?>

<div class="wrap swal-fields-editor-wrap">
    <div class="swal-loader-overlay"><div class="swal-loading-css-big"></div></div>
    <?php
    /**
     *
     * This hook is for the header bar
     *
     */
    do_action('swal_admin_header_bar');
    ?>
<div class="swal-wrap-inner">
<h1><?php esc_html_e('StranoWeb Ajax Login settings', 'sw-ajax-login') ?></h1>

<form method="post" action="options.php" id="swal-admin-form">
    <?php 
    settings_fields( SWAL_PLUGIN_SETTINGS_PAGE . '-group' );
    do_settings_sections( SWAL_PLUGIN_SETTINGS_PAGE . '-group' );

    //get settings

    $swal_user_thumbnail_style           = intval(get_option('swal_user_thumbnail_style',SWAL_USER_THUMBNAIL_STYLE_DEFAULT));
    $swal_simple_layout_width            = intval(get_option('swal_simple_layout_width',SWAL_SIMPLE_LAYOUT_WIDTH));
    $swal_double_layout_width            = intval(get_option('swal_double_layout_width',SWAL_DOUBLE_LAYOUT_WIDTH));
    $swal_customize_popup                = intval(get_option('swal_customize_popup'));
    $swal_add_login_icons                = intval(get_option('swal_add_login_icons'));
    $swal_add_register_icons             = intval(get_option('swal_add_register_icons'));
    $swal_add_forgot_password_icons      = intval(get_option('swal_add_forgot_password_icons'));
    $swal_popup_color                    = sanitize_hex_color(get_option('swal_popup_color',SWAL_POPUP_COLOR));
    $swal_popup_text_color               = sanitize_hex_color(get_option('swal_popup_text_color',SWAL_POPUP_TEXT_COLOR));
    $swal_popup_secondary_text_color     = sanitize_hex_color(get_option('swal_popup_secondary_text_color',SWAL_POPUP_SECONDARY_TEXT_COLOR));
    $swal_popup_image_text_color         = sanitize_hex_color(get_option('swal_popup_image_text_color',SWAL_POPUP_IMAGE_TEXT_COLOR));
    $swal_link_color                     = sanitize_hex_color(get_option('swal_link_color',SWAL_LINK_COLOR));
    $swal_buttons_color                  = sanitize_hex_color(get_option('swal_buttons_color',SWAL_LINK_COLOR));
    $swal_redirect_after_login           = intval(get_option('swal_redirect_after_login',SWAL_REDIRECT_AFTER_LOGIN));
    $swal_redirect_after_logout          = intval(get_option('swal_redirect_after_logout',SWAL_REDIRECT_AFTER_LOGOUT));
    $swal_logged_in_redirect             = intval(get_option('swal_logged_in_redirect',SWAL_LOGGED_IN_REDIRECT));
    $swal_custom_redirect_after_login    = esc_attr(get_option('swal_custom_redirect_after_login'));
    $swal_custom_redirect_after_login    = ltrim($swal_custom_redirect_after_login, '/');
    $swal_custom_redirect_after_logout   = esc_attr(get_option('swal_custom_redirect_after_logout'));
    $swal_custom_redirect_after_logout   = ltrim($swal_custom_redirect_after_logout, '/');
    $swal_logged_in_redirect_custom_page    = esc_attr(get_option('swal_logged_in_redirect_custom_page'));
    $swal_logged_in_redirect_custom_page    = ltrim($swal_logged_in_redirect_custom_page, '/');
    $swal_menu_item_text                 = intval(get_option('swal_menu_item_text',SWAL_MENU_ITEM_TEXT));
    $swal_popup_layout_style             = intval(get_option('swal_popup_layout_style',SWAL_POPUP_LAYOUT_STYLE));
    $swal_add_overlay_login              = intval(get_option('swal_add_overlay_login',SWAL_ADD_OVERLAY_LOGIN));
    $swal_add_overlay_logout             = intval(get_option('swal_add_overlay_logout'));
    $swal_add_overlay_register           = intval(get_option('swal_add_overlay_register',SWAL_ADD_OVERLAY_REGISTER));
    $swal_add_overlay_password           = intval(get_option('swal_add_overlay_password',SWAL_ADD_OVERLAY_PASSWORD));
    $swal_overlay_color                  = sanitize_hex_color(get_option('swal_overlay_color',SWAL_OVERLAY_COLOR));
    $swal_logout_overlay_color           = sanitize_hex_color(get_option('swal_logout_overlay_color',SWAL_LOGOUT_OVERLAY_COLOR));
    $swal_add_socials_login              = intval(get_option('swal_add_socials_login',SWAL_ADD_SOCIALS_LOGIN));
    $swal_add_native_socials_login       = intval(get_option('swal_add_native_socials_login'));
    $swal_use_social_profile_picture     = intval(get_option('swal_use_social_profile_picture'));
    $users_can_register                  = intval(get_option('users_can_register',SWAL_DISABLE_NEW_USER_REGISTRATION));
    $swal_register_no_email_to_user      = intval( get_option('swal_register_no_email_to_user', 0) );
    $swal_register_form_type             = intval( get_option('swal_register_form_type', 0) );
    $swal_no_password_text               = esc_attr(get_option('swal_no_password_text',__(SWAL_NO_PASSWORD_TEXT,'sw-ajax-login')));
    $swal_menu_item_style                = intval(get_option('swal_menu_item_style',SWAL_MENU_ITEM_STYLE));
    $swal_overlay_opacity                = intval(get_option('swal_overlay_opacity',SWAL_OVERLAY_OPACITY));
    $swal_logout_overlay_opacity         = intval(get_option('swal_logout_overlay_opacity',SWAL_OVERLAY_OPACITY));
    $swal_menu_to_append                 = is_array(get_option('swal_menu_to_append')) ? array_map('esc_attr',get_option('swal_menu_to_append')) : esc_attr(get_option('swal_menu_to_append'));
    $swal_login_bg_image_alignment   = intval(get_option('swal_login_bg_image_alignment',SWAL_LOGIN_BG_IMAGE_ALIGNMENT));
    $swal_register_bg_image_alignment   = intval(get_option('swal_register_bg_image_alignment',SWAL_REGISTER_BG_IMAGE_ALIGNMENT));
    $swal_password_bg_image_alignment   = intval(get_option('swal_password_bg_image_alignment',SWAL_PASSWORD_BG_IMAGE_ALIGNMENT));
    $swal_logout_bg_image_alignment   = intval(get_option('swal_logout_bg_image_alignment',SWAL_LOGOUT_BG_IMAGE_ALIGNMENT));
    $swal_add_social_login_to_woocommerce       = intval(get_option('swal_add_social_login_to_woocommerce'));
    $swal_add_native_twitter_login       = intval(get_option('swal_add_native_twitter_login'));
    $swal_twitter_id                  = esc_attr(get_option('swal_twitter_id'));
    $swal_twitter_secret_key          = esc_attr(get_option('swal_twitter_secret_key'));
    $swal_social_icons_theme             = intval(get_option('swal_social_icons_theme',SWAL_SOCIAL_ICONS_THEME));
    $swal_login_remember_credentials     = intval(get_option('swal_login_remember_credentials',SWAL_LOGIN_REMEMBER_CREDENTIALS));
    $swal_min_password_length           = intval(get_option('swal_min_password_length',SWAL_MIN_PASSWORD_LENGTH));
    $swal_social_icons_position         = intval(get_option('swal_social_icons_position',SWAL_SOCIAL_ICONS_POSITION));
    $swal_add_terms_link                 = intval(get_option('swal_add_terms_link'));
    $swal_show_password_reset_password_email = esc_attr(get_option('swal_show_password_reset_password_email'));
    $swal_menu_item_link_to           = intval(get_option('swal_menu_item_link_to',SWAL_MENU_ITEM_LINK_TO));
    $swal_menu_item_custom_link_to    = esc_attr(get_option('swal_menu_item_custom_link_to'));
    $swal_menu_item_custom_link_to    = ltrim($swal_menu_item_custom_link_to, '/');
    $swal_add_menu_li_class            = sanitize_html_classes(get_option('swal_add_menu_li_class'));
    $swal_add_menu_li_a_class            = sanitize_html_classes(get_option('swal_add_menu_li_a_class'));
    $swal_add_menu_li_a_ul_li_class            = sanitize_html_classes(get_option('swal_add_menu_li_a_ul_li_class'));
    $swal_add_menu_li_a_ul_li_a_class            = sanitize_html_classes(get_option('swal_add_menu_li_a_ul_li_a_class'));
    $swal_termsconditions_link_to    = intval(get_option('swal_termsconditions_link_to'));
    //$swal_termsconditions_link_to    = ltrim($swal_termsconditions_link_to, '/');
    $swal_termsconditions_text      = esc_attr(get_option('swal_termsconditions_text',SWAL_GDPR_CONSENT_TEXT));
    $swal_termsconditionsintro_text      = esc_attr(get_option('swal_termsconditionsintro_text',SWAL_GDPR_CONSENTINTRO_TEXT));
    $swal_pagina_account            = esc_attr(get_option('swal_pagina_account'));
    $swal_pagina_account_default    = intval(get_option('swal_pagina_account_default',SWAL_PAGINA_ACCOUNT_DEFAULT));
    $swal_additional_css            = esc_attr(get_option('swal_additional_css'));
    $swal_popup_close_icon_position      = intval(get_option('swal_popup_close_icon_position'));
    $swal_disable_nonces                = intval(get_option('swal_disable_nonces'));
    // Auto Popup
    $swal_enable_autopopup                = intval(get_option('swal_enable_autopopup'));
    $swal_autopopup_delay                 = get_option('swal_autopopup_delay') ? intval(get_option('swal_autopopup_delay')) : SWAL_AUTOPOPUP_DELAY;

    //Login, Register, Lost password and logout texts
    $swal_text_login                = html_entity_decode(strip_tags(get_option('swal_text_login')));
    $swal_register_login            = html_entity_decode(strip_tags(get_option('swal_register_login')));
    $swal_forgot_password_login     = html_entity_decode(strip_tags(get_option('swal_forgot_password_login')));
    $swal_logout_login              = html_entity_decode(strip_tags(get_option('swal_logout_login',__('Do you want to logout?','sw-ajax-login'))));

    $homeurl    = home_url();

    $tab_premium = esc_html__('Premium Version','sw-ajax-login');
    if (SWAL_P)
        $tab_premium = esc_html__('Features','sw-ajax-login');


     ?>

    <div class="tab_orizz_edit" id="tabs_edit">
        <?php

            /**
             *
             * This hook is for the tabs menu
             *
             */
            do_action('swal_admin_tabs_menu');

            ?>
    </div>

    <div id="sw-ajax-login-admin-form" class="swal-tabscontent">

        <?php
            /**
             *
             * This hook is for tabs content
             *
             */
            do_action('swal_admin_tabs_content');
        ?>

    <!-- Popup apparence -->
        <div id="tab1" class="tab_content">

            <h3><?php esc_html_e('Popup apparence','sw-ajax-login') ?></h3>
            <table class="form-table">

                <tr valign="top">
                <th scope="row"><label for="swal_popup_layout_style"><?php esc_html_e("Popup layout style",'sw-ajax-login') ?></label></th>
                <td>
                    <div class="cc-selector">
                        <?php 

                        $item = array(
                                    array(__('Simple (no image)','sw-ajax-login'),'layout-radiobuttons','swal_simple_layout_width'),
                                    array(__('Double column (Image on the left)','sw-ajax-login'),'layout-radiobuttons','swal_double_layout_width'),
                                    );
                            foreach($item as $key => $value) {
                                    echo '<input type="radio" class="sw-radiobuttonshowoncheck" data-group="'.$value[1].'" data-target="'.$value[2].'" id="swal_popup_layout_style'.$key.'" name="swal_popup_layout_style" value="'.$key.'"'.checked( $swal_popup_layout_style, $key,false ).'>
                                    <label class="drinkcard-cc swal_popup_layout_style'.$key.'" for="swal_popup_layout_style'.$key.'">'.$value[0].'</label>';
                                }

                            $item = array(
                                    array(__('<span class="sw-premium-text">Premium</span> - Simple (with background image)','sw-ajax-login'),'layout-radiobuttons','swal_simple_layout_width'),
                                    array(__('<span class="sw-premium-text">Premium</span> - Double column (Image on the right)','sw-ajax-login'),'layout-radiobuttons','swal_double_layout_width'),
                                    array(__('<span class="sw-premium-text">Premium</span> - Double column (Image on the right)','sw-ajax-login'),'layout-radiobuttons','swal_double_layout_width'),
                                    array(__('<span class="sw-premium-text">Premium</span> - Double column (Full background image, form on left)','sw-ajax-login'),'layout-radiobuttons','swal_double_layout_width'),
                                    array(__('<span class="sw-premium-text">Premium</span> - Login & Register tabs','sw-ajax-login'),'layout-radiobuttons','swal_simple_layout_width'),
                                    array(__('<span class="sw-premium-text">Premium</span> - Login & Register tabs (with background image)','sw-ajax-login'),'layout-radiobuttons','swal_simple_layout_width'),
                                    );
                            foreach($item as $key => $value) {
                                $newkey = intval($key)+2;
                                    echo '<div class="drinkcard-cc swal_popup_layout_style'.$newkey.'" for="swal_popup_layout_style'.$newkey.'">'.$value[0].'</div>';
                                }

                        ?>
                    </div>
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"></th>
                <td><input type="checkbox" class="sw-showoncheck" data-target="customize-popup" id="swal_customize_popup" name="swal_customize_popup" value="1" <?php echo checked( '1', $swal_customize_popup, true ); ?>/>
                    <label for="swal_customize_popup" class="sw-right-label"><?php esc_html_e('Customize popup and main overlay','sw-ajax-login'); ?></label>
                <p class="description">
                    <?php esc_html_e('Customize Popup width & color and overlay color & opacity','sw-ajax-login'); ?>
                </p>
                <div class="customize-popup inner-div-settings">
                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_popup_color"><?php esc_html_e('Popup color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_popup_color" name="swal_popup_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_popup_color; ?>">
                        </div>

                        <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td layout-radiobuttons swal_simple_layout_width">
                            <label for="swal_simple_layout_width" class="sw-right-label"><?php esc_html_e('Popup width','sw-ajax-login'); ?></label>
                            <div class="range-slider">
                              <input id="swal_simple_layout_width" name="swal_simple_layout_width" class="range-slider__range" type="range" value="<?php echo $swal_simple_layout_width ?>" min="340" max="640" step="2">
                              <span class="range-slider__value-wrapper"><span class="range-slider__value"><?php echo $swal_simple_layout_width ?></span> px</span>
                            </div>
                        </div>

                         <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td layout-radiobuttons swal_double_layout_width">
                            <label for="swal_double_layout_width" class="sw-right-label"><?php esc_html_e('Popup width','sw-ajax-login'); ?></label>
                            <div class="range-slider">
                              <input id="swal_double_layout_width" name="swal_double_layout_width" class="range-slider__range" type="range" value="<?php echo $swal_double_layout_width ?>" min="800" max="960" step="2">
                              <span class="range-slider__value-wrapper"><span class="range-slider__value"><?php echo $swal_double_layout_width ?></span> px</span>
                            </div>
                        </div>
                    </div>

                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_main_overlay_color"><?php esc_html_e('Main overlay color','sw-ajax-login'); ?></label>
                            <p class="description sw-premium-text">
                                <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                            </p>
                        </div>
                        <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_main_overlay_opacity" class="sw-right-label"><?php esc_html_e('Opacity','sw-ajax-login'); ?></label>
                            <p class="description sw-premium-text">
                                <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                            </p>
                        </div>
                    </div>


                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_popup_secondary_text_color"><?php esc_html_e('Text color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_popup_text_color" name="swal_popup_text_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_popup_text_color; ?>">
                        </div>
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_popup_image_text_color"><?php esc_html_e('Text over images color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_popup_image_text_color" name="swal_popup_image_text_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_popup_image_text_color; ?>">
                        </div>
                    </div>

                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_popup_secondary_text_color"><?php esc_html_e('Secondary text color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_popup_secondary_text_color" name="swal_popup_secondary_text_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_popup_secondary_text_color; ?>">
                        </div>
                    </div>

                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_link_color"><?php esc_html_e('Link color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_link_color" name="swal_link_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_link_color; ?>">
                        </div>
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_buttons_color"><?php esc_html_e('Buttons color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_buttons_color" name="swal_buttons_color" class="clear swal-colorpicker  settings-select" value="<?php echo $swal_buttons_color; ?>">
                        </div>
                    </div>

                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_loader_background_color"><?php esc_html_e('Loader background color','sw-ajax-login'); ?></label>
                            <p class="description sw-premium-text">
                                <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                            </p>
                        </div>
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_loader_text_color"><?php esc_html_e('Loader text color','sw-ajax-login'); ?></label>
                            <p class="description sw-premium-text">
                                <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                            </p>
                        </div>
                    </div>
                </div>
                </td>
                </tr>
                <tr valign="top">
                <th scope="row"><label for="swal_popup_close_icon_position"><?php esc_html_e("Close button position:",'sw-ajax-login') ?></label></th>
                <td>
                        <?php 
                            $item = array();
                            $item[] = __("Inside the popup",'sw-ajax-login');
                            $item[] = __("Outside the popup",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<label class="sw-label-radio-buttons"><input type="radio" id="swal_popup_close_icon_position'.$key.'" name="swal_popup_close_icon_position" value="'.$key.'"'.checked( $swal_popup_close_icon_position, $key,false ).'> '.$value.'</label>';
                                } 
                        ?>
                        <p class="clear description">
                        <?php esc_html_e('Note: Inside the popup doesn\'t work on tabs layout where the close button is always outside the popup.' ,'sw-ajax-login');
                         ?></p>
                     </td>
                 </tr>
                 <?php
                    /**
                     *
                     * This hook fires after popup layout and before image overlay setting
                     *
                     */
                    do_action('swal_settings_after_popup_layout');
                ?>
                <tr valign="top">
                <th scope="row"></th>
                <td><input type="checkbox" class="sw-showoncheck" data-target="swal-overlay-setting" id="swal_add_overlay_login" name="swal_add_overlay_login" value="1" <?php echo checked( '1', $swal_add_overlay_login, true ); ?>/>
                    <label for="swal_add_overlay_login" class="sw-right-label"><?php esc_html_e('Add image overlay','sw-ajax-login'); ?></label>
                <p class="description">
                    <?php esc_html_e('Overlay is helpfull to make the text more readable','sw-ajax-login'); ?>
                </p>
                <div class="swal-overlay-setting inner-div-settings">
                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_overlay_color"><?php esc_html_e('Overlay color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_overlay_color" name="swal_overlay_color" class="swal-colorpicker" value="<?php echo $swal_overlay_color; ?>">
                        </div>
                        <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_overlay_opacity"><?php esc_html_e('Opacity','sw-ajax-login'); ?></label>
                            <div class="range-slider">
                              <input id="swal_overlay_opacity" name="swal_overlay_opacity" class="range-slider__range" type="range" value="<?php echo $swal_overlay_opacity ?>" min="0" max="100" step="5">
                      <span class="range-slider__value-wrapper"><span class="range-slider__value"><?php echo $swal_overlay_opacity ?></span> %</span>
                            </div>
                        </div>
                    </div>
                </div>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_additional_css"><?php esc_html_e('Custom CSS','sw-ajax-login'); ?></label></th>
                <td>
                    <textarea id="swal_additional_css" name="swal_additional_css" rows="10" class="settings-textarea"><?php echo $swal_additional_css ?></textarea>
                    <p class="description">
                        <?php esc_html_e('You can add additional css here. For security reasons, css comments, @import and @charset are removed.','sw-ajax-login');
                         ?>
                    </p>
                </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_1',true,array('id' => 'submit_tab_1' )); ?>

            <!-- Premium Advise -->
            <div class="clear description-section">
                <h3><?php esc_html_e('Different layout models','sw-ajax-login'); ?></h3>
                <p><?php esc_html_e('Need a different layout for your website or more custom settings?','sw-ajax-login');
                 ?><br/>
                 <?php esc_html_e('With Premium version you\'ll get all the available layouts and all the StranoWeb Ajax Login features!','sw-ajax-login');
                 ?></p>
                 <div>
                    <div class="swal-premium-button left">
                        <a href="<?php echo esc_html(SWAL_PREMIUM_BUY_LINK) ?>" target="_blank"><i class="fa fa-shopping-cart fa-lg" aria-hidden="true"></i> <?php esc_html_e('Upgrade to the Premium version', 'sw-ajax-login') ?></a>
                    </div>
                </div>
            </div>
        </div>

    <!-- Logged menu -->
        <div id="tab6" class="tab_content">
            <h3><?php esc_html_e('Menu', 'sw-ajax-login') ?></h3>
            <table class="form-table">

                 <tr valign="top">
                <th scope="row"><label for="swal_menu_to_append"><?php esc_html_e('Add Login menu item to:','sw-ajax-login'); ?></label></th>
                <td>
                    <?php 
                        
                        $menus = wp_get_nav_menus();
                        $check_menu_exists = true;
                        $submenu_name = '';

                        // check if the Login item submenu location has the menu,
                        // if yes doens't show on the list to avoid an infinite loop is it's selected.
                        $theme_locations = get_nav_menu_locations();
                        if (isset($theme_locations['swal-user-menu-item'])) {
                            $menu_obj = get_term( $theme_locations['swal-user-menu-item'], 'nav_menu' );
                            $submenu_name = isset($menu_obj->slug) ? $menu_obj->slug : '';
                        }
                        

                        foreach ( $menus as $location ) {
                            $args = array(
                            'id'            => 'swal_menu_to_append_'.$location->slug,
                            'name'          => 'swal_menu_to_append[]',
                            'value'         => $swal_menu_to_append,
                            'input_value'   => $location->slug,
                            'label'         => esc_html__($location->name),
                            'label_class'   => 'sw-right-label',
                                );
                            if ( $location->slug != $submenu_name ) {
                                 echo '<div class="clear margin-bottom-5 ">';
                                        swal_checkbox_ios_style( $args );
                                echo '</div>';
                            } 
                                    
                        }
                   
                    ?>

                    <?php
                        if (!$check_menu_exists) {
                            echo '<div class="sw-info-box sw-info-box-info hide" id="swal_menu_alert"><p>';
                            printf( esc_html__( 'This navigation menu has not a menu yet, please go to %s and create one.', 'sw-ajax-login' ) , '<a href="'. $homeurl.'/wp-admin/nav-menus.php">'. esc_html__('Appearance -> Menus','sw-ajax-login').'</a>' );
                            echo '</p></div>';
                            
                        }
                    ?>
                    <p class="description">
                    <?php esc_html_e('Select the menu you want to add the item \'Login\'. It\'s usually the header menu, but you can select any other menu.' ,'sw-ajax-login');
                     ?>
                </p>
                <?php
                
                ?>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_menu_item_text"><?php esc_html_e('Login menu text','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_menu_item_text" id="swal_menu_item_text" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Login",'sw-ajax-login');
                            $item[] = __("Login/Register",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_menu_item_text, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <p class="clear description">
                    <?php esc_html_e('Select the text that will appear on the login menu item.' ,'sw-ajax-login');
                     ?></p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_user_thumbnail_style"><?php esc_html_e('Thumbnail Style','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_user_thumbnail_style" id="swal_user_thumbnail_style" class="settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Don't show thumbnail",'sw-ajax-login');
                            $item[] = __("Squared",'sw-ajax-login');
                            $item[] = __("Rounded",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_user_thumbnail_style, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <p class="description">
                            <?php esc_html_e('This is how the user thumbnail will appear on the main menu when the user is logged','sw-ajax-login'); ?>
                        </p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_menu_item_style"><?php esc_html_e("Once logged show on main menu:",'sw-ajax-login') ?></label></th>
                <td>
                        <?php 
                            $item = array();
                            $item[] = __("Logout link",'sw-ajax-login');
                            $item[] = __("Username",'sw-ajax-login');
                            $item[] = __("Name Surname",'sw-ajax-login');
                            $item[] = __("Surname Name",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<label class="sw-label-radio-buttons"><input type="radio" id="swal_menu_item_style'.$key.'" name="swal_menu_item_style" value="'.$key.'"'.checked( $swal_menu_item_style, $key,false ).'> '.$value.'</label>';
                                } 
                        ?>
                        <p class="clear description">
                        <?php esc_html_e('Note: if name or surname are not available will display the username.' ,'sw-ajax-login');
                         ?></p> 
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_menu_item_link_to"><?php esc_html_e('Menu item links to:','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_menu_item_link_to" id="swal_menu_item_link_to" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __("No link",'sw-ajax-login');
                            $item[] = __("Custom link",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_menu_item_link_to, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <div id="menu-item-custom-link" class="clear padding-top hide text_long">
                        <code><?php echo $homeurl ?>/</code>
                        <input placeholder="<?php esc_html_e('Insert page','sw-ajax-login'); ?>" type="text" id="swal_menu_item_custom_link_to" name="swal_menu_item_custom_link_to" class="regular-text code text_long settings-select" value="<?php echo $swal_menu_item_custom_link_to; ?>">
                        <p class="clear description"><?php esc_html_e('If the field is empty no link will be applied to the menu item.','sw-ajax-login') ?></p>
                    </div>
                </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_6',true,array('id' => 'submit_tab_6' )); ?>
        </div>

    <!-- Login via Socials -->
        <div id="tab7" class="tab_content">            

            <h3><?php esc_html_e('Login via Socials','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"></th>
                <td>
                    <input type="checkbox" class="sw-showoncheck" data-target="internal-socials-login" id="swal_add_socials_login" name="swal_add_socials_login" value="1" <?php echo checked( '1', $swal_add_socials_login, true ); ?>/>
                    <label for="swal_add_socials_login" class="sw-right-label"><?php esc_html_e('Add socials login','sw-ajax-login'); ?></label>
                    <p class="description wrapper-tab_content">
                        <?php esc_html_e('This option enables login via socials.','sw-ajax-login');
                         ?>
                    </p>
                </td>
                </tr>

                <tr valign="top" class="internal-socials-login">
                <th scope="row"><label for="swal_social_icons_position"><?php esc_html_e('Social Icons position','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_social_icons_position" id="swal_social_icons_position" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Below login button",'sw-ajax-login');
                            $item[] = __("On top, before username and password fields",'sw-ajax-login');
                            $item[] = __("Between username and password fields and login button",'sw-ajax-login');
                            $item[] = __("Inside image container",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_social_icons_position, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <p class="clear description wrapper-tab_content">
                        <?php esc_html_e('This option set the position of social login icons, below login button, below input fields or inside the image container.','sw-ajax-login');
                         ?>
                    </p>
                </td>
                </tr>

                <tr valign="top" class="internal-socials-login">
                <th scope="row"></th>
                <td>
                    <div class="inner-div-settings">
                        <div class="padding-td">
                            <input type="checkbox" id="swal_use_social_profile_picture" name="swal_use_social_profile_picture" value="1" <?php echo checked( '1', $swal_use_social_profile_picture, true ); ?>/>
                            <label for="swal_use_social_profile_picture" class="sw-right-label"><?php esc_html_e('Replace Avatar image with social profile picture','sw-ajax-login'); ?></label>
                            <p class="description">
                                <?php esc_html_e('By enabling this option Social profile picture will be shown instead of WordPress user avatar.','sw-ajax-login');
                                 ?>
                            </p>
                        </div>
                        <div class="native-socials-login">

                            <!-- Facebook API keys -->
                            <div class="padding-td">
                                <input disabled="disabled" type="checkbox" name="swal_add_native_facebook_login" value="0"/>
                                <label for="swal_add_native_facebook_login" class="sw-right-label"><i class="fa fa-facebook"></i><?php esc_html_e('Facebook','sw-ajax-login'); ?></label>
                                <div class="gc">
                                    <div class="sw-grid span-1 wrapper-tab_content">
                                    <p class="description sw-premium-text">
                                        <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                                    </p>
                                    </div>
                                </div>
                            </div>

                            <!-- Twitter API keys -->
                            <div class="clear padding-td">
                                <input type="checkbox" class="sw-showoncheck" data-target="swal-twitter" id="swal_add_native_twitter_login" name="swal_add_native_twitter_login" value="1" <?php echo checked( '1', $swal_add_native_twitter_login, true ); ?>/>
                                <label for="swal_add_native_twitter_login" class="sw-right-label"><i class="fa fa-twitter"></i><?php esc_html_e('Twitter','sw-ajax-login'); ?></label>
                                <div class="gc swal-twitter">
                                    <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                        <label for="swal_twitter_id"><?php esc_html_e('Twitter App ID','sw-ajax-login'); ?></label>
                                        <input type="text" id="swal_twitter_id" name="swal_twitter_id" class="clear settings-select" value="<?php echo $swal_twitter_id; ?>">
                                    </div>
                                    <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                        <label for="swal_twitter_secret_key"><?php esc_html_e('Twitter App Secret','sw-ajax-login'); ?></label>
                                        <input type="text" id="swal_twitter_secret_key" name="swal_twitter_secret_key" class="clear settings-select" value="<?php echo $swal_twitter_secret_key; ?>">
                                    </div>
                                    <div class="sw-grid span-1 wrapper-tab_content">
                                    <a href="#" class="slidedown-div" data-item="twitter-info"><?php esc_html_e('How to get Twitter API keys','sw-ajax-login'); ?> (?)</a>
                                    <div id="twitter-info" class="hide">
                                        <ol class="description">
                                            <li>
                                                <?php esc_html_e('Login into your Twitter account and go to ','sw-ajax-login'); ?><a href="https://apps.twitter.com/app/new" target="_blank">https://apps.twitter.com/app/new</a>
                                            </li>
                                            <li><?php esc_html_e("Click on 'Add a New App' button. A popup will open. Enter the name of the app as you wish and your email, then click on 'Create New App ID' button.",'sw-ajax-login'); ?></li>
                                            <li><?php esc_html_e("Enter your desired Application Name, Description and your website address (points 4 & 5) making sure to enter the full address including the http:// or https://.", 'sw-ajax-login'); ?></li>
                                            <li><?php esc_html_e("Site URL",'sw-ajax-login'); ?>: <input value="<?php echo $homeurl; ?>" readonly="readonly" type="text" class="settings-select"></li>
                                            <li><?php esc_html_e("Callback URL",'sw-ajax-login'); ?>: <input value="<?php echo $homeurl; ?>" readonly="readonly" type="text" class="settings-select"></li> 
                                            <li><?php esc_html_e("After creating your Twitter Application click on the tab that says 'Keys and Access Tokens' and get Consumer key(API Key) and Consumer secret(API secret).", 'sw-ajax-login'); ?></li>
                                            <li><strong><?php esc_html_e("Important: ",'sw-ajax-login'); ?></strong><?php esc_html_e("To get the user's email address please go to app's permission tab and in additional Permissions there you will find a checkbox to request for user email address. Please enable it. To enable it you need to enter privacy policy url and terms of service url.", 'sw-ajax-login'); ?></li>              
                                        </ol>
                                    </div>
                                    <hr/>
                                    </div>
                                </div>
                            </div>

                            <!-- Google+ API keys -->
                            <div class="clear padding-td">
                                <input disabled="disabled" type="checkbox" value="0"/>
                                <label for="swal_add_native_google_login" class="sw-right-label"><i class="signin-google"></i><?php esc_html_e('Google','sw-ajax-login'); ?></label>
                                <div class="gc">
                                    <div class="sw-grid span-1 wrapper-tab_content">
                                    <p class="description sw-premium-text">
                                        <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                                    </p>
                                    </div>
                                </div>
                            </div>

                            <!-- Linkedin API keys -->
                            <div class="clear padding-td">
                                <input disabled="disabled" type="checkbox" value="0"/>
                                <label for="swal_add_native_linkedin_login" class="sw-right-label"><i class="fa fa-linkedin"></i><?php esc_html_e('Linkedin','sw-ajax-login'); ?></label>
                                <div class="gc">
                                    <div class="sw-grid span-1 wrapper-tab_content">
                                    <p class="description sw-premium-text">
                                        <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                                    </p>
                                    </div>
                                </div>
                                </div>
                            </div>

                            <?php 
                            //check if woocommerce is installed and activated
                            if ( class_exists( 'WooCommerce' ) ) {
                                  
                                ?>
                            <div class="clear padding-td">
                                <input type="checkbox" id="swal_add_social_login_to_woocommerce" name="swal_add_social_login_to_woocommerce" value="1" <?php echo checked( '1', $swal_add_social_login_to_woocommerce, true ); ?>/>
                                <label for="swal_add_social_login_to_woocommerce" class="sw-right-label"><?php esc_html_e('Add to WooCommerce login form','sw-ajax-login'); ?></label>
                                <p class="description">
                                <?php esc_html_e('This option adds Stranoweb Ajax Login native social login buttons to WooCommerce login form','sw-ajax-login');
                                 ?>
                                </p>
                            </div>
                                <?php } ?>

                            <h3><?php esc_html_e('Icons theme','sw-ajax-login'); ?></h3>
                            <?php 
                            $item = array();
                            $item[3] = __('Theme 4','sw-ajax-login');
                            $item[4] = __('Theme 5','sw-ajax-login');
                            foreach($item as $key => $value) {
                                $key = $key+1;
                            echo '<div class="padding-td clear">';
                                    echo '<input type="radio" id="swal_social_icons_theme'.$key.'" name="swal_social_icons_theme" value="'.$key.'"'.checked( $swal_social_icons_theme, $key,false ).'>
                                    <label class="sw-right-label" for="swal_social_icons_theme'.$key.'">'.$value.'</label>';
                                    ?>
                                    <div class="swal-login-networks theme<?php echo $key ?> clear">
                                      <div class="social-networks">
                                        <div class="fb-login-button item-disabled">
                                            <div class="swal-icon-block icon-facebook">
                                                <i class="fa fa-facebook"></i>
                                                <span class="swal-long-login-text"><?php esc_html_e('Login with Facebook','sw-ajax-login'); ?></span>
                                            </div>
                                        </div>
                                      </div>

                                      <div class="social-networks">
                                        <div class="twitter-login-button">
                                            <div class="swal-icon-block icon-twitter">
                                                <i class="fa fa-twitter"></i>
                                                <span class="swal-long-login-text"><?php esc_html_e('Login with Twitter','sw-ajax-login'); ?></span>
                                            </div>
                                        </div>
                                      </div>

                                      <div class="social-networks">
                                        <div class="google-login-button item-disabled">
                                            <div class="swal-icon-block icon-google">
                                                <i class="signin-google"></i>
                                                <span class="swal-long-login-text"><?php esc_html_e('Login with Google','sw-ajax-login'); ?></span>
                                            </div>
                                        </div>
                                      </div>

                                      <div class="social-networks">
                                        <div class="linkedin-login-button item-disabled">
                                            <div class="swal-icon-block icon-linkedin">
                                                <i class="fa fa-linkedin"></i>
                                                <span class="swal-long-login-text"><?php esc_html_e('Login with Linkedin','sw-ajax-login'); ?></span>
                                            </div>
                                        </div>
                                      </div>
                                    </div>
                                    <div class="clear"></div>
                                </div>
                                <?php
                             } 
                        ?>

                        </div>
                    </div>
                </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_7',true,array('id' => 'submit_tab_7' )); ?>

            <!-- Premium Advise -->
            <div class="clear description-section">
                <h3><?php esc_html_e('Want more social logins?','sw-ajax-login'); ?></h3>
                <p><?php esc_html_e('Social Login makes it easier for visitors to your site to become customers by using their existing social media credentials to register on your site.','sw-ajax-login');
                 ?></p>
                 <p><?php esc_html_e('With Premium version you\'ll get more social logins and all the StranoWeb Ajax Login features!','sw-ajax-login');
                 ?></p>
                 <div>
                    <div class="swal-premium-button left">
                        <a href="<?php echo esc_html(SWAL_PREMIUM_BUY_LINK) ?>"><i class="fa fa-shopping-cart fa-lg" aria-hidden="true"></i> <?php esc_html_e('Upgrade to the Premium version', 'sw-ajax-login') ?></a>
                    </div>
                </div>
            </div>
        </div>

    <!-- Redirects & Permalink -->
        <div id="tab8" class="tab_content">

            <h3><?php esc_html_e('Redirects','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"><label for="swal_redirect_after_login"><?php esc_html_e('After login redirect to:','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_redirect_after_login" id="swal_redirect_after_login" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Homepage",'sw-ajax-login');
                            $item[] = __("Same page",'sw-ajax-login');
                            $item[] = __("Custom page",'sw-ajax-login');
                            $item[] = __("Admin dashboard",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_redirect_after_login, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <div id="custom-page-redirect" class="clear padding-top hide text_long">
                        <code><?php echo $homeurl ?>/</code>
                        <input placeholder="<?php esc_html_e('Insert page to redirect','sw-ajax-login'); ?>" type="text" id="swal_custom_redirect_after_login" name="swal_custom_redirect_after_login" class="regular-text code text_long settings-select" value="<?php echo $swal_custom_redirect_after_login; ?>">
                        <p class="clear description"><?php esc_html_e('If the field is empty the user will be redirected to the homepage.','sw-ajax-login') ?></p>
                    </div>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_redirect_after_logout"><?php esc_html_e('After logout redirect to:','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_redirect_after_logout" id="swal_redirect_after_logout" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Homepage",'sw-ajax-login');
                            $item[] = __("Same page",'sw-ajax-login');
                            $item[] = __("Custom page",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_redirect_after_logout, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <div id="custom-page-redirect-logout" class="clear padding-top hide text_long">
                        <code><?php echo $homeurl ?>/</code>
                        <input placeholder="<?php esc_html_e('Insert page to redirect','sw-ajax-login'); ?>" type="text" id="swal_custom_redirect_after_logout" name="swal_custom_redirect_after_logout" class="regular-text code text_long settings-select" value="<?php echo $swal_custom_redirect_after_logout; ?>">
                        <p class="clear description"><?php esc_html_e('If the field is empty the user will be redirected to the homepage.','sw-ajax-login') ?></p>
                    </div>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_logged_in_redirect"><?php esc_html_e('Login page -> If already logged in:','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_logged_in_redirect" id="swal_logged_in_redirect" class="floatL margin-right settings-select">
                        <?php
                            $item = array();
                            $item[] = __('Show "User already logged in" message','sw-ajax-login');
                            $item[] = __("Redirect to homepage",'sw-ajax-login');
                            $item[] = __("Redirect to custom page",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_logged_in_redirect, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <div id="loggedin-custom-page-redirect" class="clear padding-top hide text_long">
                        <code><?php echo $homeurl ?>/</code>
                        <input placeholder="<?php esc_html_e('Insert page to redirect','sw-ajax-login'); ?>" type="text" id="swal_logged_in_redirect_custom_page" name="swal_logged_in_redirect_custom_page" class="regular-text code text_long settings-select" value="<?php echo $swal_logged_in_redirect_custom_page; ?>">
                    </div>
                    <p class="clear description"><?php esc_html_e('You can set up the action to do if an already logged in user lands on Login, Register or Forgot Password page.','sw-ajax-login') ?> <?php esc_html_e('If the field is empty the user will be redirected to the homepage.','sw-ajax-login') ?></p>
                </td>
                </tr>
            </table>

            <h3><?php esc_html_e('WordPress admin dashboard access','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"></th>
                <td>
                    <p class="description sw-premium-text">
                        <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                    </p>
                </td>
                </tr>
            </table>

            <h3><?php esc_html_e('Permalink','sw-ajax-login') ?></h3>
            <?php
                        if (swal_check_permalink_for_index()) {
                            echo '<div class="sw-info-box sw-info-box-info"><p><i class="fa fa-info-circle fa-2x"></i> ';
                            esc_html_e( 'Your permalink structure contains /index.php. It’s not search engine friendly & you are missing out the opportunity to rank higher in the search engine. We reccomend to remove it.');
                            echo '<br/>';
                            printf( esc_html__( 'To fix it go to %s and click on Post name & save the permalink structure.', 'sw-ajax-login' ) , '<a href="'. $homeurl.'/wp-admin/options-permalink.php">'. esc_html__('Settings> Permalink','sw-ajax-login').'</a>' );
                            echo '</p></div>';
                        }
                    ?> 
            <p><?php esc_html_e('SWAL replaces WordPress default login, registration and forgot password pages with its own modules. All SWAL ajax pages are also accessible via direct URL, you can customize the base to suit your needs.','sw-ajax-login') ?>
                <br/><?php 

                $current_permalink = swal_get_permalink();

                esc_html_e('Links to forms are: ','sw-ajax-login') ?></p>

               <ol>
                    <li><code><?php echo wp_login_url() ? wp_login_url() : esc_html__( 'You must assign the Login page!', 'sw-ajax-login' ); ?></code></li>
                    <li><code><?php echo wp_registration_url() ? wp_registration_url() : esc_html__( 'You must assign the Register page!', 'sw-ajax-login' ); ?></code></li>
                    <li><code><?php echo wp_lostpassword_url() ? wp_lostpassword_url() : esc_html__( 'You must assign the Forgot Password page!', 'sw-ajax-login' ); ?></code></li>
                    <li><code><?php echo swal_resetpassword_url() ? swal_resetpassword_url() : esc_html__( 'You must assign the Reset Password page!', 'sw-ajax-login' ); ?></code></li>
                    <li><code><?php echo swal_logout_url() ? swal_logout_url() : esc_html__( 'You must assign the Logout page!', 'sw-ajax-login' ); ?></code></li>
                </ol>
                
            <table class="form-table">

                <tr valign="top">
                <th scope="row">
                    <input type="radio" id="swal_pagina_account_default" name="swal_pagina_account_default" value="0"<?php echo checked( $swal_pagina_account_default, '0',false ); ?>>
                    <label for="swal_pagina_account_default" class="sw-right-label"><?php esc_html_e('Default','sw-ajax-login'); ?></label>
                </th>
                <td>
                    <code class="clear"><?php echo $homeurl . '/' . swal_check_permalink_for_index() . SWAL_PAGINA_ACCOUNT; ?></code>      
                </td>
                </tr>

                <tr valign="top">
                <th scope="row">
                    <input type="radio" id="swal_pagina_account_custom" name="swal_pagina_account_default" value="1"<?php echo checked( $swal_pagina_account_default, '1',false ); ?>>
                    <label for="swal_pagina_account_custom" class="sw-right-label"><?php esc_html_e('Custom base','sw-ajax-login'); ?></label>
                </th>
                <td>
                    <code><?php echo $homeurl . '/' . swal_check_permalink_for_index(); ?></code>
                    <input placeholder="<?php esc_html_e('Insert base','sw-ajax-login'); ?>" type="text" id="swal_pagina_account" name="swal_pagina_account" class="regular-text code text_long settings-select" value="<?php echo $swal_pagina_account; ?>">       
                    <p class="clear description"><?php esc_html_e('If the field is empty it will use the default permalink.','sw-ajax-login') ?></p>               
                </td>
                </tr>

                <?php
                    /**
                     *
                     * This hook is for Social login settings
                     *
                     */
                    do_action('swal_permalinks_section');
                ?>  
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_8',true,array('id' => 'submit_tab_8' )); ?>
        </div>

    <!-- Login Window -->
        <div id="tab2" class="tab_content">
            <h3><?php esc_html_e('Login window','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"><label for="swal_login_remember_credentials"><?php esc_html_e('Remember credentials','sw-ajax-login'); ?></label></th>
                <td>
                    <select name="swal_login_remember_credentials" id="swal_login_remember_credentials" class="settings-select">
                        <?php
                            $item = array();
                            $item[] = __("Always",'sw-ajax-login');
                            $item[] = __("Never",'sw-ajax-login');
                            $item[] = __("Show checkbox",'sw-ajax-login');
                            foreach($item as $key => $value) {
                                    echo '<option value="'.$key.'"'.selected( $swal_login_remember_credentials, $key,false ).'>'.$value.'</option>';
                                } 
                        ?>
                    </select>
                    <p class="description">
                            <?php esc_html_e('You can choose if website remembers user\'s credentials, never or shows a checkbox to let the user decide.','sw-ajax-login'); ?>
                        </p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_min_password_length"><?php esc_html_e("Minimum password length",'sw-ajax-login') ?></label></th>
                <td>
                    <select name="swal_min_password_length" id="swal_min_password_length" class="settings-select">
                        <?php 
                            for ($n = 0; $n <= 10; $n+=1) {
                                    echo '<option value="'.$n.'"'.selected( $swal_min_password_length, $n,false ).'>'.$n.'</option>';
                                } 
                        ?>
                    </select>
                    <p class="description">
                            <?php esc_html_e('Select the minimum password length, 0 means no minimum length required.','sw-ajax-login'); ?>
                        </p>
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"></th>
                <td><input type="checkbox" id="swal_add_login_icons" name="swal_add_login_icons" value="1" <?php echo checked( '1', $swal_add_login_icons, true ); ?>/>
                    <label for="swal_add_login_icons" class="sw-right-label"><?php esc_html_e('Add icons to login input fields','sw-ajax-login'); ?></label>
                    <p class="description">
                        <?php esc_html_e('By enabling this option fontawesome icons will be added to username and password input fields.','sw-ajax-login'); ?>
                    </p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Login background image",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="gc">
                            <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                <?php sw_ajax_login_image_uploader( 'swal_ajax_login_background', $width = 115, $height = 115 ); ?>
                                <p class="description">
                                    <?php esc_html_e('The image the will appear as background of login popup if you have chosen the popup layout style with image','sw-ajax-login'); ?>
                                </p>
                            </div>
                            <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                                <h4><?php esc_html_e("Background position",'sw-ajax-login') ?></h4>
                                <div class="cc-selector">
                                    <?php
                                        swal_set_alignment_radiobuttons('swal_login_bg_image_alignment', $swal_login_bg_image_alignment);
                                    ?>
                                </div>
                            </div>
                        </div>
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Login text (optional)",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="wrapper-tab_content">
                            <?php
                            $settings = array(
                            'teeny' => true,
                            'tinymce' => array(
                                'external_plugins' => wp_json_encode(array(
                                                            'keyup_event' => SWAL_PLUGIN_JS . "/admin-for-tinymce.js",
                                                        ))
                            ),
                            'media_buttons' => false,
                            'editor_height' => 180,
                            'tabindex' => 1
                            );
                            wp_editor($swal_text_login, 'swal_text_login', $settings);
                            ?>
                        </div>
                    </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_2',true,array('id' => 'submit_tab_2' )); ?>
        </div>

    <!-- Register Window -->
        <div id="tab3" class="tab_content">
            <h3><?php esc_html_e('Register window','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"></th>
                <td>
                    <input type="checkbox" class="sw-showoncheck" data-target="swal-disable-new-user-registration" id="users_can_register" name="users_can_register" value="1" <?php echo checked( '1', $users_can_register, true ); ?>/>
                    <label for="users_can_register" class="sw-right-label"><?php esc_html_e('Anyone can register','sw-ajax-login'); ?></label>
                <p class="description">
                    <?php esc_html_e('By checking this option you enable new users registering on your site.','sw-ajax-login');
                     ?>
                </p>
                </td>
                </tr>

                <tr valign="top" class="swal-disable-new-user-registration">
                <th scope="row"></th>
                <td>
                    <div class="gc text_long inner-div-settings">
                        <div class="sw-grid span-1 padding-td">
                            <label for="swal_register_form_type"><?php esc_html_e('Form type','sw-ajax-login'); ?></label>
                            <?php 
                                $item = array(
                                    array(__('Show the input password fields','sw-ajax-login'),'form-type-radiobuttons','form-type-with-pwd'),
                                    array(__('Don\'t show the input password fields, password will be automatically generated and sent on email','sw-ajax-login'),'form-type-radiobuttons','form-type-without-pwd'),
                                    );
                                foreach($item as $key=>$value) {
                                        echo '<label class="sw-label-radio-buttons"><input type="radio" class="sw-radiobuttonshowoncheck" data-group="'.$value[1].'" data-target="'.$value[2].'" id="swal_register_form_type'.$key.'" name="swal_register_form_type" value="'.$key.'"'.checked( $swal_register_form_type, $key,false ).'> '.$value[0].'</label>';
                                    } 
                            ?>
                        </div>
                    </div>

                    <div id="swal_register_form_type_intructions" class="gc text_long inner-div-settings form-type-radiobuttons form-type-radiobuttons form-type-without-pwd">
                        <div id="swal_register_form_type1" class="sw-grid span-2-3 tablet-1 mobile-1 padding-td">
                            <label for="swal_no_password_text"><?php esc_html_e('Registration instruction','sw-ajax-login'); ?></label>
                            <input placeholder="<?php esc_html_e(SWAL_NO_PASSWORD_TEXT,'sw-ajax-login'); ?>" type="text" id="swal_no_password_text" name="swal_no_password_text" class="regular-text text_long wrapper-tab_content" value="<?php echo $swal_no_password_text; ?>">
                            <p class="clear description"><?php esc_html_e('Insert here what user will receive after registration.','sw-ajax-login') ?></p>
                        </div>
                    </div>
                </td>
                </tr>
                
                <?php
                    /**
                     *
                     * This hook is for reCAPTCHA settings
                     *
                     */
                    do_action('swal_admin_register_tab');
                    ?>
                <tr valign="top" class="swal-disable-new-user-registration">
                    <th scope="row"></th>
                    <td><input type="checkbox" id="swal_register_no_email_to_user" name="swal_register_no_email_to_user" value="1" <?php echo checked( '1', $swal_register_no_email_to_user, true ); ?>/>
                        <label for="swal_register_no_email_to_user" class="sw-right-label"><?php esc_html_e('Don\'t send email to user after registration','sw-ajax-login'); ?></label>
                        <p class="description">
                            <?php esc_html_e('By enabling this option users won\'t receive the confirmation email from our plugin, this can be usefull if you are using a third party plugin for new user activation.','sw-ajax-login');
                             ?>
                        </p>
                    </td>
                </tr>
            </table>

            <table class="form-table" class="swal-disable-new-user-registration">
            <h3 class="swal-disable-new-user-registration"><?php esc_html_e('GDPR consent','sw-ajax-login') ?></h3>
                <tr valign="top" class="swal-disable-new-user-registration">
                <th scope="row"></th>
                <td><input type="checkbox" class="sw-showoncheck" data-target="swal-termsconditions-link" id="swal_add_terms_link" name="swal_add_terms_link" value="1" <?php echo checked( '1', $swal_add_terms_link, true ); ?>/>
                    <label for="swal_add_terms_link" class="sw-right-label"><?php esc_html_e('Add GDPR consent checkbox','sw-ajax-login'); ?></label>
                    <p class="description">
                        <?php esc_html_e('This option adds a mandatory checkbox for GDPR consent with a link to Terms & Conditions page.','sw-ajax-login');
                         ?>
                    </p>
                    <div id="swal-termsconditions-link" class="clear text_long padding-top swal-termsconditions-link">
                        <div class="gc inner-div-settings">
                            <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                                <label for="swal_termsconditions_text"><?php esc_html_e('GDPR consent text','sw-ajax-login'); ?></label>
                                <input placeholder="<?php esc_html_e(SWAL_GDPR_CONSENT_TEXT,'sw-ajax-login'); ?>" type="text" id="swal_termsconditions_text" name="swal_termsconditions_text" class="regular-text text_long wrapper-tab_content" value="<?php echo $swal_termsconditions_text; ?>">
                                <p class="clear description"><?php esc_html_e('Insert here the text to get user consent on form submition.','sw-ajax-login') ?></p>
                            </div>
                        </div>

                        <div class="gc inner-div-settings">
                            <div class="sw-grid span-1-3 tablet-1 mobile-1 padding-td">
                                <label for="swal_termsconditions_link_to"><?php esc_html_e('Privacy page','sw-ajax-login'); ?></label>
                                <?php 
                                $args = array(
                                    'depth'                 => 0,
                                    'child_of'              => 0,
                                    'selected'              => $swal_termsconditions_link_to,
                                    'echo'                  => 1,
                                    'name'                  => 'swal_termsconditions_link_to',
                                    'id'                    => null,
                                    'class'                 => 'clear regular-text text_long settings-select',
                                    'show_option_none'      => __('--- None ---','sw-ajax-login'),
                                    'show_option_no_change' => null,
                                    'option_none_value'     => null,
                                    );
                                wp_dropdown_pages($args); ?>
                                <p class="clear description"><?php esc_html_e('A link to privacy page will be appended to the consent message.','sw-ajax-login') ?></p>
                            </div>
                            <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                <label for="swal_termsconditionsintro_text"><?php esc_html_e('Link text','sw-ajax-login'); ?></label>
                                <input placeholder="<?php esc_html_e(SWAL_GDPR_CONSENTINTRO_TEXT,'sw-ajax-login'); ?>" type="text" id="swal_termsconditionsintro_text" name="swal_termsconditionsintro_text" class="regular-text text_long wrapper-tab_content" value="<?php echo $swal_termsconditionsintro_text; ?>">
                                <p class="clear description"><?php esc_html_e('Insert here privacy link text if you want it different from the page name.','sw-ajax-login') ?></p>
                            </div>
                        </div>
                    </div>
                </td>
                </tr>
            </table>
            
            <table class="form-table" class="swal-disable-new-user-registration">
            <h3 class="swal-disable-new-user-registration"><?php esc_html_e('Appearance','sw-ajax-login') ?></h3>
                <tr valign="top" class="swal-disable-new-user-registration">
                <th scope="row"></th>
                <td><input type="checkbox" id="swal_add_register_icons" name="swal_add_register_icons" value="1" <?php echo checked( '1', $swal_add_register_icons, true ); ?>/>
                    <label for="swal_add_register_icons" class="sw-right-label"><?php esc_html_e('Add icons to registration input fields','sw-ajax-login'); ?></label>
                    <p class="description">
                        <?php esc_html_e('By enabling this option fontawesome icons will be added to new user registration input fields.','sw-ajax-login'); ?>
                    </p>
                </td>
                </tr>

                <tr valign="top" class="swal-disable-new-user-registration">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Register background image",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="gc">
                            <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                <?php sw_ajax_login_image_uploader( 'swal_ajax_register_background', $width = 115, $height = 115 ); ?>
                                <p class="description">
                                    <?php esc_html_e('The image the will appear as background on register popup if you have chosen the popup layout style with image','sw-ajax-login'); ?>
                                </p>
                            </div>
                            <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                                <h4><?php esc_html_e("Background position",'sw-ajax-login') ?></h4>
                                <div class="cc-selector">
                                    <?php
                                        swal_set_alignment_radiobuttons('swal_register_bg_image_alignment', $swal_register_bg_image_alignment);
                                    ?>
                                </div>
                            </div>
                        </div>
                    </td>
                </tr>

                <tr valign="top" class="swal-disable-new-user-registration">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Register text (optional)",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="wrapper-tab_content">
                            <?php
                            $settings = array(
                            'teeny' => true,
                            'tinymce' => array(
                                'external_plugins' => wp_json_encode(array(
                                                            'keyup_event' => SWAL_PLUGIN_JS . "/admin-for-tinymce.js",
                                                        ))
                            ),
                            'media_buttons' => false,
                            'editor_height' => 180,
                            'tabindex' => 1
                            );
                            wp_editor($swal_register_login, 'swal_register_login', $settings);
                            ?>
                        </div>
                    </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_3',true,array('id' => 'submit_tab_3' )); ?>
        </div>

    <!-- Forgot Password Window -->
        <div id="tab4" class="tab_content">
            <h3><?php esc_html_e('Forgot Password window','sw-ajax-login') ?></h3>
            <table class="form-table">

                <tr valign="top">
                <th scope="row"><?php esc_html_e('Reset Password confirmation email','sw-ajax-login'); ?></th>
                <td><input type="checkbox" id="swal_show_password_reset_password_email" name="swal_show_password_reset_password_email" value="1" <?php echo checked( '1', $swal_show_password_reset_password_email, true ); ?>/>
                    <label for="swal_show_password_reset_password_email" class="sw-right-label"><?php esc_html_e('Show new password','sw-ajax-login'); ?></label>
                <p class="description">
                    <?php 
                    esc_html_e('Upon successful reset password, the user will receive a new password confirmation email. ','sw-ajax-login');
                    esc_html_e('By enabling this option the new password will be shown on email content.','sw-ajax-login');
                     ?>
                </p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"></th>
                <td><input type="checkbox" id="swal_add_forgot_password_icons" name="swal_add_forgot_password_icons" value="1" <?php echo checked( '1', $swal_add_forgot_password_icons, true ); ?>/>
                    <label for="swal_add_forgot_password_icons" class="sw-right-label"><?php esc_html_e('Add icon to email input field','sw-ajax-login'); ?></label>
                    <p class="description">
                        <?php esc_html_e('By enabling this option fontawesome icons will be added to email input field.','sw-ajax-login'); ?>
                    </p>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Forgot password background image",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="gc">
                            <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                <?php sw_ajax_login_image_uploader( 'swal_ajax_forgot_password_background', $width = 115, $height = 115 ); ?>
                                <p class="description">
                                    <?php esc_html_e('The image the will appear as background on forgot password popup if you have chosen the popup layout style with image','sw-ajax-login'); ?>
                                </p>
                            </div>
                            <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                                <h4><?php esc_html_e("Background position",'sw-ajax-login') ?></h4>
                                <div class="cc-selector">
                                    <?php
                                        swal_set_alignment_radiobuttons('swal_password_bg_image_alignment', $swal_password_bg_image_alignment);
                                    ?>
                                </div>
                            </div>
                        </div>
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Register text (optional)",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="wrapper-tab_content">
                                <?php
                                $settings = array(
                                'teeny' => true,
                                'tinymce' => array(
                                    'external_plugins' => wp_json_encode(array(
                                                                'keyup_event' => SWAL_PLUGIN_JS . "/admin-for-tinymce.js",
                                                            ))
                                ),
                                'media_buttons' => false,
                                'editor_height' => 180,
                                'tabindex' => 1
                            );
                            wp_editor($swal_forgot_password_login, 'swal_forgot_password_login', $settings);
                            ?>
                        </div>
                    </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_4',true,array('id' => 'submit_tab_4' )); ?>
        </div>

    <!-- Logout Window -->
        <div id="tab5" class="tab_content">
            <h3><?php esc_html_e('Logout window','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Logout background image",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="gc">
                            <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                                <?php sw_ajax_login_image_uploader( 'swal_ajax_logout_background', $width = 115, $height = 115 ); ?>
                                <p class="description">
                                    <?php esc_html_e('The image the will appear as background on logout popup if you have chosen the popup layout style with image','sw-ajax-login'); ?>
                                </p>
                            </div>
                            <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                                <h4><?php esc_html_e("Background position",'sw-ajax-login') ?></h4>
                                <div class="cc-selector">
                                    <?php
                                        swal_set_alignment_radiobuttons('swal_logout_bg_image_alignment', $swal_logout_bg_image_alignment);
                                    ?>
                                </div>
                            </div>
                        </div>
                    </td>
                </tr>

                <tr valign="top">
                <th scope="row"></th>
                <td><input type="checkbox" class="sw-showoncheck" data-target="swal-logout-overlay-setting" id="swal_add_overlay_logout" name="swal_add_overlay_logout" value="1" <?php echo checked( '1', $swal_add_overlay_logout, true ); ?>/>
                    <label for="swal_add_overlay_logout" class="sw-right-label"><?php esc_html_e('Customize logout image overlay','sw-ajax-login'); ?></label>
                <p class="description">
                    <?php esc_html_e('By enabling this option you can set a different overlay color and opacity to logout window','sw-ajax-login'); ?>
                </p>
                <div class="swal-logout-overlay-setting inner-div-settings">
                    <div class="gc">
                        <div class="sw-grid span-1-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_logout_overlay_color"><?php esc_html_e('Overlay color','sw-ajax-login'); ?></label>
                            <input type="text" id="swal_logout_overlay_color" name="swal_logout_overlay_color" class="swal-colorpicker" value="<?php echo $swal_logout_overlay_color; ?>">
                        </div>
                        <div class="sw-grid span-2-3 tablet-1-2 mobile-1 padding-td">
                            <label for="swal_logout_overlay_opacity"><?php esc_html_e('Opacity','sw-ajax-login'); ?></label>
                            <div class="range-slider">
                              <input id="swal_logout_overlay_opacity" name="swal_logout_overlay_opacity" class="range-slider__range" type="range" value="<?php echo $swal_logout_overlay_opacity ?>" min="0" max="100" step="5">
                      <span class="range-slider__value-wrapper"><span class="range-slider__value"><?php echo $swal_logout_overlay_opacity ?></span> %</span>
                            </div>
                        </div>
                    </div>
                </div>
                </td>
                </tr>

                <tr valign="top">
                <th scope="row"><label for="swal_list_columns"><?php esc_html_e("Logout text (optional)",'sw-ajax-login') ?></label></th>
                    <td>
                        <div class="wrapper-tab_content">
                        <?php
                        $settings = array(
                        'teeny' => true,
                        'tinymce' => array(
                                'external_plugins' => wp_json_encode(array(
                                                            'keyup_event' => SWAL_PLUGIN_JS . "/admin-for-tinymce.js",
                                                        ))
                            ),
                        'media_buttons' => false,
                        'editor_height' => 180,
                        'tabindex' => 1
                            );
                            wp_editor($swal_logout_login, 'swal_logout_login', $settings);
                            ?>
                        </div>
                    </td>
                </tr>
            </table>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_5',true,array('id' => 'submit_tab_5' )); ?>
        </div>


    <!-- Emails Window -->
        <div id="tab10" class="tab_content">
            <h2 class="swal-title center"><?php esc_html_e('Emails','sw-ajax-login') ?></h2>
            <div class="gc-np background-pair">
                <div class="sw-grid span-1-2 tablet-1 mobile-1 inner-text vertical-middle">
                    <h3><?php esc_html_e('Design your emails', 'sw-ajax-login') ?></h3>
                    <p><?php esc_html_e('With', 'sw-ajax-login') ?> <strong><?php esc_html_e('Stranoweb Ajax Login Premium', 'sw-ajax-login') ?></strong> <?php esc_html_e('You can easily customize the email notifications received by users on registration and password recovery.', 'sw-ajax-login') ?>
                        <br/><?php esc_html_e('They will perfectly match your website design!', 'sw-ajax-login') ?></p>
                    <ul class="swal-features-list">
                        <li><?php esc_html_e('Customize email colors and layout', 'sw-ajax-login') ?></li>
                        <li><?php esc_html_e('Emails content editor', 'sw-ajax-login') ?></li>
                        <li><?php esc_html_e('Add your logo', 'sw-ajax-login') ?></li>
                        <li><?php esc_html_e('Add images', 'sw-ajax-login') ?></li>
                        <li><?php esc_html_e('Footer content editor', 'sw-ajax-login') ?></li>
                    </ul>
                </div>
                <div class="sw-grid span-1-2 tablet-1 mobile-1 vertical-middle">
                    <div class="swal-image-container">
                        <img src="<?php echo SWAL_PLUGIN_DOCS_IMAGES . '/swal-templates-email.jpg'; ?>" alt="" class="center span-1"/>
                    </div>
                </div>
                <div>
                    <div class="swal-premium-button">
                        <a href="<?php echo esc_html(SWAL_PREMIUM_BUY_LINK) ?>"><i class="fa fa-shopping-cart fa-lg" aria-hidden="true"></i> <?php esc_html_e('Upgrade to the Premium version', 'sw-ajax-login') ?></a>
                    </div>
                </div>
            </div>

        </div>

    <!-- Advanced -->
        <div id="tab11" class="tab_content">
            <h3><?php esc_html_e('Advanced','sw-ajax-login') ?></h3>
            <table class="form-table">
            
                <tr valign="top">
                <th scope="row"></th>
                <td>
                    <?php
                    $args = array(
                            'id'            => 'swal_disable_nonces',
                            'name'          => 'swal_disable_nonces',
                            'value'         => $swal_disable_nonces,
                            'input_value'   => 1,
                            'class'         => 'sw-showoncheck',
                            'label'         => esc_html__('Disable SWAL nonce','sw-ajax-login'),
                            'label_class'   => 'sw-right-label',
                                );
                            swal_checkbox_ios_style( $args );
                            ?>
                    <p class="description wrapper-tab_content">
                        <?php esc_html_e('StranoWeb Ajax Login adds nonce to login, register, forgot password and change password to increase security. As the nonce is added as a hidden form element, it will also end up being cached by some caching plugins. This can cause some issues with nonce verification (403 error on admin-ajax.php)' ,'sw-ajax-login');
                         ?><br/>
                        <u><?php esc_html_e('Note: WordPress default forms for Login, Register, Forgot Password and Change Password don\'t have nonce validation!','sw-ajax-login');
                         ?></u>
                    </p>
                </td>
                </tr>
            </table>

            <h3><?php esc_html_e('Auto Popup','sw-ajax-login') ?></h3>
            <table class="form-table">
                <tr valign="top">
                <th scope="row"></th>
                <td>
                    <?php
                    $args = array(
                            'id'            => 'swal_enable_autopopup',
                            'name'          => 'swal_enable_autopopup',
                            'value'         => $swal_enable_autopopup,
                            'input_value'   => 1,
                            'class'         => 'sw-showoncheck',
                            'data'          => array(
                                                'target' => 'swal-auto-popup',
                                                ),
                            'label'         => esc_html__('Enable auto popup','sw-ajax-login'),
                            'label_class'   => 'sw-right-label',
                                );
                            swal_checkbox_ios_style( $args );
                            ?>
                    <p class="description wrapper-tab_content">
                        <?php esc_html_e('Enabling this option the Login popup will auto open if the user isn\'t logged in.','sw-ajax-login');
                         ?>
                    </p>
                </td>
                </tr>

                <tr valign="top" class="swal-auto-popup">
                <th scope="row"><?php esc_html_e('Delay in opening popup' ,'sw-ajax-login');
                     ?></th>
                <td>

                    <div class="loggedin_menu_item_radiobuttons clear text_long settings-select swal_loggedin_custom_text inner-div-settings">
                        <input placeholder="<?php esc_html_e('Insert delay','sw-ajax-login'); ?>" type="number" id="swal_autopopup_delay" name="swal_autopopup_delay" class="text_long settings-select" value="<?php echo $swal_autopopup_delay; ?>">
                    </div>
                    <p class="clear description">
                    <?php esc_html_e('Delay in milliseconds. 1000 = 1s, 0 = no delay. The delay begins when the page is fully loaded.' ,'sw-ajax-login');
                     ?>
                    </p>   
                </td>
                </tr>

                <tr valign="top" class="swal-auto-popup">
                <th scope="row"></th>
                <td>
                    <div class="swal-auto-popup-custom-pages padding-top">
                        <h4><?php esc_html_e('Auto popup on these pages','sw-ajax-login') ?></h4>
                        <p class="description sw-premium-text">
                            <?php esc_html_e('Available on Premium version','sw-ajax-login'); ?>
                        </p>
                    </div>
                </td>
                </tr>

            </table>
            <!-- Premium Advise -->
            <div class="clear description-section">
                <h3><?php esc_html_e('Need more settings?','sw-ajax-login'); ?></h3>
                <p>
                 <?php esc_html_e('With Premium version you\'ll get the full control of StranoWeb Ajax Login with more options to improve speed performance!','sw-ajax-login');
                 ?></p>
                 <div>
                    <div class="swal-premium-button left">
                        <a href="<?php echo esc_html(SWAL_PREMIUM_BUY_LINK) ?>" target="_blank"><i class="fa fa-shopping-cart fa-lg" aria-hidden="true"></i> <?php esc_html_e('Upgrade to the Premium version', 'sw-ajax-login') ?></a>
                    </div>
                </div>
            </div>
            <?php submit_button(esc_html__('Save Changes','sw-ajax-login'),'primary','submit_tab_11',true,array('id' => 'submit_tab_11' )); ?>
        </div>



    <!-- Premium description -->
        <div id="tab9" class="tab_content">
            <?php swal_display_premium_features(); ?>
        </div>



    </div>
    

</form>
</div>
</div>
<?php

}



function sw_ajax_login_image_uploader( $name, $width, $height ) {

    // Set variables
    $options = esc_attr(get_option( $name ));
    $default_image = plugins_url('img/no-image.jpg', __FILE__);

    if ( !empty( $options ) ) {
        $image_attributes = wp_get_attachment_image_src( $options, array( $width, $height ) );
        $src = $image_attributes[0];
        $value = $options;
    } else {
        $src = $default_image;
        $value = '';
    }

    $text = __( 'Upload', 'sw-ajax-login' );

    // Print HTML field
    echo '
        <div class="upload">
            <img data-src="' . $default_image . '" src="' . $src . '" width="' . $width . 'px" height="' . $height . 'px" />
            <div>
                <input type="hidden" name="' . $name . '" id="' . $name . '" value="' . $value . '" />
                <button type="submit" class="upload_image_button button">' . $text . '</button>
                <button type="submit" class="remove_image_button button">&times;</button>
            </div>
        </div>
    ';
}

?>